﻿#define DEBUG_AGENT

using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using LocationLogger.Resources;
using Microsoft.Phone.Scheduler;

namespace LocationLogger
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Sample code to localize the ApplicationBar
            //BuildLocalizedApplicationBar();
        }

        #region Background location tracking

        PeriodicTask periodicTask = null;
        string periodicTaskName = "LocationLogger";

        private void RemoveAgent(string name)
        {
            try
            {
                ScheduledActionService.Remove(name);
            }
            catch (Exception)
            {
            }
        }

        private void StopTracking()
        {
            RemoveAgent(periodicTaskName);
        }

        private void StartTracking()
        {
            periodicTask = ScheduledActionService.Find(periodicTaskName) as PeriodicTask;

            // If the task already exists and the IsEnabled property is false, background
            // agents have been disabled by the user
            if (periodicTask != null && !periodicTask.IsEnabled)
            {
                MessageBox.Show("Background agents for this application have been disabled by the user.");
                return;
            }

            // If the task already exists and background agents are enabled for the
            // application, you must remove the task and then add it again to update 
            // the schedule
            if (periodicTask != null && periodicTask.IsEnabled)
            {
                RemoveAgent(periodicTaskName);
            }

            periodicTask = new PeriodicTask(periodicTaskName);

            // The description is required for periodic agents. This is the string that the user
            // will see in the background services Settings page on the device.
            periodicTask.Description = "Location Logger";
            ScheduledActionService.Add(periodicTask);

            // If debugging is enabled, use LaunchForTest to launch the agent in one minute.
#if(DEBUG_AGENT)
            ScheduledActionService.LaunchForTest(periodicTaskName, TimeSpan.FromSeconds(60));
#endif
        }

        #endregion

        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            base.OnNavigatedTo(e);

            // When we navigate to the page - put the semi-completed log text in the display

            // Get a reference to the parent application
            App thisApp = App.Current as App;

            // Put the text onto the display
            LogTextBlock.Text = thisApp.LogText;

            // Now set up the text in the background text button

            periodicTask = ScheduledActionService.Find(periodicTaskName) as PeriodicTask;

            if (periodicTask == null)
            {
                trackingControlButton.Content = "Start Tracking";
            }
            else
            {
                trackingControlButton.Content = "Stop Tracking";
            }
        }

        private void trackingControlButton_Click(object sender, RoutedEventArgs e)
        {
            periodicTask = ScheduledActionService.Find(periodicTaskName) as PeriodicTask;

            if (periodicTask == null)
            {
                StartTracking();
                trackingControlButton.Content = "Stop Tracking";
            }
            else
            {
                StopTracking();
                trackingControlButton.Content = "Start Tracking";
            }
        }

        private void clearLogButton_Click(object sender, RoutedEventArgs e)
        {
            // Get a reference to the parent application
            App thisApp = App.Current as App;

            thisApp.LogText = "";
            LogTextBlock.Text = thisApp.LogText;
            thisApp.SaveLogToIsolatedStorageFile();
        }

        private void refreshButton_Click(object sender, RoutedEventArgs e)
        {
            // Get a reference to the parent application
            App thisApp = App.Current as App;

            thisApp.LoadLogFromIsolatedStorageFile();

            // Put the text onto the display
            LogTextBlock.Text = thisApp.LogText;

        }

        // Sample code for building a localized ApplicationBar
        //private void BuildLocalizedApplicationBar()
        //{
        //    // Set the page's ApplicationBar to a new instance of ApplicationBar.
        //    ApplicationBar = new ApplicationBar();

        //    // Create a new button and set the text value to the localized string from AppResources.
        //    ApplicationBarIconButton appBarButton = new ApplicationBarIconButton(new Uri("/Assets/AppBar/appbar.add.rest.png", UriKind.Relative));
        //    appBarButton.Text = AppResources.AppBarButtonText;
        //    ApplicationBar.Buttons.Add(appBarButton);

        //    // Create a new menu item with the localized string from AppResources.
        //    ApplicationBarMenuItem appBarMenuItem = new ApplicationBarMenuItem(AppResources.AppBarMenuItemText);
        //    ApplicationBar.MenuItems.Add(appBarMenuItem);
        //}
    }
}